@@ -36,3 +36,22 @@ class WorkspaceResources:
         return self.client._requestor.get(url='/'.join([self._base_api_url,
             'workspaces', ws_id, 'resources']), page_number=page_number,
             page_size=page_size)
+
+    def list_all(self, ws_id=None):
+        """
+        GET /workspaces/:workspace_id/resources
+
+        Built-in logic to enumerate all pages in list response for
+        cases where there are more than 100 Workspace Resoures.
+
+        Returns object (dict) with two arrays: `data` and `included`.
+        """
+        if ws_id is not None:
+            ws_id = ws_id
+        elif self.ws_id:
+            ws_id = self.ws_id
+        else:
+            raise MissingWorkspace
+
+        return self.client._requestor._list_all(url='/'.join([self._base_api_url,
+            'workspaces', ws_id, 'resources']))
